spawn_std

Function spawn_std 

pub fn spawn_std<T>(
    command: &mut Command,
    spawn: impl FnMut(&mut Command) -> Result<T, Error>,
) -> Result<T, Error>
Spawn a caller-built command under the fork lock, retrying while the program is transiently busy (ETXTBSY) and once if the host refused it as an APE image.