Module backend_lib

Module backend_lib 

Backend-facing helpers for v1 broker consumers.

This module is intentionally platform-neutral. Windows DuplicateHandle and Unix SCM_RIGHTS transports will live in platform modules; backend consumers can use this layer to validate and classify handed-off payloads once those transports deliver a candidate connection.

Re-exports

pub use crate::broker::server::HandoffToken;
pub use crate::broker::server::HandoffTokenError;
pub use crate::broker::server::HandoffTokenStore;
pub use crate::broker::server::HandoffTokenStoreConfig;
pub use crate::broker::server::DEFAULT_HANDOFF_TOKEN_COLLISION_ATTEMPTS;
pub use crate::broker::server::DEFAULT_HANDOFF_TOKEN_TTL;
pub use crate::broker::server::DEFAULT_MAX_PENDING_HANDOFF_TOKENS;
pub use crate::broker::server::HANDOFF_TOKEN_BYTES;
pub use accept_handed_off::accept_handed_off;
pub use accept_handed_off::parse_handoff_token;
pub use accept_handed_off::AcceptedHandoff;
pub use accept_handed_off::HandedOffPayload;
pub use accept_handed_off::HandoffAcceptance;
pub use accept_handed_off::HandoffRejectionReason;
pub use accept_handed_off::RejectedHandoff;
pub use wire::read_handoff_offer;
pub use wire::respond_to_handoff_offer;
pub use wire::serve_handoff_offer;
pub use wire::write_handoff_ack;
pub use wire::BackendHandoffWireError;

Modules

accept_handed_off
Acceptance classifier for backend-side handed-off connections.
wire
Backend-side wire handling for broker handoff offers (#354, slice 6).