pub enum IdentityError {
MissingEndpoint,
InvalidSha256Length(usize),
CurrentExe(Error),
Io(Error),
}Expand description
Errors returned while normalizing daemon identity.
Variants
MissingEndpoint
The protobuf daemon identity did not include an IPC endpoint.
InvalidSha256Length(usize)
The protobuf daemon identity had an executable digest with the wrong size.
CurrentExe(Error)
The current executable path could not be read.
Io(Error)
A filesystem operation failed while hashing the executable.