pub enum ProbeError {
EndpointMismatch,
EndpointResponse(EndpointProbeError),
VerifyPid(VerifyPidError),
}Expand description
Errors returned while probing a backend endpoint.
Variants
EndpointMismatch
The caller-provided endpoint did not match the expected daemon endpoint.
EndpointResponse(EndpointProbeError)
The endpoint did not answer the active identity probe as expected.
VerifyPid(VerifyPidError)
The daemon process identity could not be verified.