pub enum BackendHttpReadyError {
Decode(DecodeError),
PortOutOfRange(u32),
}Expand description
Errors raised by decode_and_register.
Variants
Decode(DecodeError)
The incoming bytes did not decode as a BackendHttpReady.
PortOutOfRange(u32)
The decoded port did not fit in a u16 (i.e. > 65535).