#[repr(i32)]pub enum StorageDisposition {
PruneOnUninstall = 0,
PreserveAcrossUninstall = 1,
PruneWhenDormant = 2,
NeverPrune = 3,
PruneOnCrash = 4,
}Variants
PruneOnUninstall = 0
PreserveAcrossUninstall = 1
e.g., soldr’s pinned_bin
PruneWhenDormant = 2
NeverPrune = 3
user-owned data
PruneOnCrash = 4
only valid while writing process alive
Implementations
Sourceimpl StorageDisposition
impl StorageDisposition
Sourcepub fn from_i32(value: i32) -> Option<StorageDisposition>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<StorageDisposition>
Use the TryFrom<i32> implementation instead
Converts an i32 to a StorageDisposition, or None if value is not a valid variant.
Sourceimpl StorageDisposition
impl StorageDisposition
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.