pub struct CacheRoot {
pub path: String,
pub kind: i32,
pub estimated_size_bytes: u64,
pub disposition: i32,
pub labels: HashMap<String, String>,
pub quota: Option<Quota>,
pub teardown_hook: Option<TeardownHook>,
pub exclude_globs: Vec<String>,
pub platform_paths: HashMap<String, String>,
pub ownership: Option<Ownership>,
pub endpoint: Option<Endpoint>,
}Fields
path: Stringabsolute path
kind: i32estimated_size_bytes: u64disposition: i32labels: HashMap<String, String>quota: Option<Quota>teardown_hook: Option<TeardownHook>exclude_globs: Vec<String>platform_paths: HashMap<String, String>alternate paths per platform
ownership: Option<Ownership>endpoint: Option<Endpoint>(namespace_id, path) for ipc endpoint roots
Implementations
Sourceimpl CacheRoot
impl CacheRoot
Sourcepub fn kind(&self) -> CacheRootKind
pub fn kind(&self) -> CacheRootKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CacheRootKind)
pub fn set_kind(&mut self, value: CacheRootKind)
Sets kind to the provided enum value.
Sourcepub fn disposition(&self) -> StorageDisposition
pub fn disposition(&self) -> StorageDisposition
Returns the enum value of disposition, or the default if the field is set to an invalid enum value.
Sourcepub fn set_disposition(&mut self, value: StorageDisposition)
pub fn set_disposition(&mut self, value: StorageDisposition)
Sets disposition to the provided enum value.