pub struct Negotiated {
pub negotiated_protocol: u32,
pub daemon_version: String,
pub backend_pipe: String,
pub warnings: Vec<String>,
pub server_capabilities: u64,
pub keepalive_interval_secs: u64,
pub handle_passed_token: Vec<u8>,
pub connection_id: u64,
}Fields
negotiated_protocol: u32daemon_version: Stringbackend_pipe: Stringpipe name client connects to
warnings: Vec<String>server_capabilities: u64keepalive_interval_secs: u64handle_passed_token: Vec<u8>present when broker used DuplicateHandle/SCM_RIGHTS handoff
connection_id: u64Trait Implementations
Sourceimpl Clone for Negotiated
impl Clone for Negotiated
Sourcefn clone(&self) -> Negotiated
fn clone(&self) -> Negotiated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Negotiated
impl Debug for Negotiated
Sourceimpl Default for Negotiated
impl Default for Negotiated
impl Eq for Negotiated
Sourceimpl Hash for Negotiated
impl Hash for Negotiated
Sourceimpl Message for Negotiated
impl Message for Negotiated
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for Negotiated
impl PartialEq for Negotiated
Sourcefn eq(&self, other: &Negotiated) -> bool
fn eq(&self, other: &Negotiated) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for Negotiated