pub struct ServiceDefinition {
pub service_name: String,
pub binary_path: String,
pub isolation: i32,
pub explicit_instance: String,
pub per_version_binary_dir: String,
pub min_version: String,
pub version_allow_list: Vec<String>,
pub labels: HashMap<String, String>,
}Fields
service_name: String[a-z0-9-]{1,64}
binary_path: Stringcanonical path to backend binary
isolation: i32PRIVATE_BROKER (default), SHARED_BROKER, EXPLICIT_INSTANCE
explicit_instance: Stringused only when isolation == EXPLICIT_INSTANCE
per_version_binary_dir: Stringcanonicalized allow-list root for backends
min_version: Stringsemver floor - refuses wanted_version below this
version_allow_list: Vec<String>optional strict pin
labels: HashMap<String, String>Implementations
Sourceimpl ServiceDefinition
impl ServiceDefinition
Sourcepub fn isolation(&self) -> BrokerIsolation
pub fn isolation(&self) -> BrokerIsolation
Returns the enum value of isolation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_isolation(&mut self, value: BrokerIsolation)
pub fn set_isolation(&mut self, value: BrokerIsolation)
Sets isolation to the provided enum value.