pub struct TeardownHook {
pub kind: i32,
pub argv: Vec<String>,
pub timeout_secs: u64,
}Fields
kind: i32argv: Vec<String>timeout_secs: u64Implementations
Sourceimpl TeardownHook
impl TeardownHook
Sourcepub fn kind(&self) -> TeardownKind
pub fn kind(&self) -> TeardownKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: TeardownKind)
pub fn set_kind(&mut self, value: TeardownKind)
Sets kind to the provided enum value.