pub struct BackendHttpReady {
pub port: u32,
}Expand description
Notification frame sent from a daemon to its broker once the daemon’s
HTTP server has bound a port. port is u16 in Rust; proto’s narrowest
integer is uint32 so the wire type is uint32 and the broker
validates the range on receipt.
Fields
port: u32Trait Implementations
Sourceimpl Clone for BackendHttpReady
impl Clone for BackendHttpReady
Sourcefn clone(&self) -> BackendHttpReady
fn clone(&self) -> BackendHttpReady
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BackendHttpReady
Sourceimpl Debug for BackendHttpReady
impl Debug for BackendHttpReady
Sourceimpl Default for BackendHttpReady
impl Default for BackendHttpReady
impl Eq for BackendHttpReady
Sourceimpl Hash for BackendHttpReady
impl Hash for BackendHttpReady
Sourceimpl Message for BackendHttpReady
impl Message for BackendHttpReady
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BackendHttpReady
impl PartialEq for BackendHttpReady
Sourcefn eq(&self, other: &BackendHttpReady) -> bool
fn eq(&self, other: &BackendHttpReady) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BackendHttpReady