pub struct GetSessionTokenResponse {
pub found: bool,
pub session_token: Vec<u8>,
}Expand description
Broker→CLI response. found = false means daemon_id has no registered
token (never launched through this broker, or already invalidated) –
session_token is empty in that case, not a zero-filled placeholder.
Fields
found: boolsession_token: Vec<u8>Trait Implementations
Sourceimpl Clone for GetSessionTokenResponse
impl Clone for GetSessionTokenResponse
Sourcefn clone(&self) -> GetSessionTokenResponse
fn clone(&self) -> GetSessionTokenResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetSessionTokenResponse
impl Debug for GetSessionTokenResponse
Sourceimpl Default for GetSessionTokenResponse
impl Default for GetSessionTokenResponse
Sourcefn default() -> GetSessionTokenResponse
fn default() -> GetSessionTokenResponse
Returns the “default value” for a type. Read more
impl Eq for GetSessionTokenResponse
Sourceimpl Hash for GetSessionTokenResponse
impl Hash for GetSessionTokenResponse
Sourceimpl Message for GetSessionTokenResponse
impl Message for GetSessionTokenResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetSessionTokenResponse
impl PartialEq for GetSessionTokenResponse
impl StructuralPartialEq for GetSessionTokenResponse