pub enum BroadcastOperation {
ReleaseHandles {
path_prefix: PathBuf,
},
Quiesce {
reason: QuiesceReason,
},
}Expand description
Broker lifecycle broadcast operation.
Variants
ReleaseHandles
Ask backends to release file handles below a path prefix.
Quiesce
Ask backends to stop accepting new work and drain.
Fields

reason: QuiesceReasonReason the backend is being asked to drain.
Implementations
Sourceimpl BroadcastOperation
impl BroadcastOperation
Sourcepub fn release_handles(path_prefix: impl Into<PathBuf>) -> Self
pub fn release_handles(path_prefix: impl Into<PathBuf>) -> Self
Build a release-handles operation for path_prefix.
Sourcepub fn quiesce(reason: QuiesceReason) -> Self
pub fn quiesce(reason: QuiesceReason) -> Self
Build a quiesce operation.