pub struct BroadcastBackend {
pub key: BackendKey,
/* private fields */
}Expand description
Testable model of one backend’s lifecycle-broadcast endpoint.
Fields
key: BackendKeyBackend key receiving broadcasts.
Implementations
Sourceimpl BroadcastBackend
impl BroadcastBackend
Sourcepub fn live(key: BackendKey) -> Self
pub fn live(key: BackendKey) -> Self
Build a live backend endpoint that acknowledges broadcasts.
Sourcepub fn dead(key: BackendKey) -> Self
pub fn dead(key: BackendKey) -> Self
Build a dead backend endpoint that should be skipped.
Sourcepub fn with_response(self, response: BroadcastBackendResponse) -> Self
pub fn with_response(self, response: BroadcastBackendResponse) -> Self
Set the modeled response returned when this backend receives a request.
Sourcepub fn received_operations(&self) -> &[BroadcastOperation]
pub fn received_operations(&self) -> &[BroadcastOperation]
Operations that reached this backend in the model.