pub enum ControlSocketError {
Connection(BrokerConnectionError),
Framing(FramingError),
AdminFrame(AdminFrameError),
EncodeFrame(EncodeError),
DecodeAdminReply(DecodeError),
}Expand description
Errors raised while dispatching a shared broker control socket frame.
Variants
Connection(BrokerConnectionError)
Hello/local-socket connection handling failed.
Framing(FramingError)
Frame read/write failed.
AdminFrame(AdminFrameError)
Admin frame validation or dispatch failed.
EncodeFrame(EncodeError)
The response frame could not be encoded.
DecodeAdminReply(DecodeError)
The admin response payload could not be decoded after dispatch.