pub enum HandoffAttemptDecision {
Attempt,
FallbackToReconnect(HandoffFallbackDecision),
}Expand description
Decision produced before or after an optional handoff attempt.
Variants
Attempt
The broker may attempt platform-specific handoff.
FallbackToReconnect(HandoffFallbackDecision)
The broker must reply with the backend endpoint and let the client reconnect.
Implementations
Sourceimpl HandoffAttemptDecision
impl HandoffAttemptDecision
Sourcepub fn fallback(&self) -> Option<&HandoffFallbackDecision>
pub fn fallback(&self) -> Option<&HandoffFallbackDecision>
Return the fallback decision when this is a reconnect fallback.