pub enum HandoffDeliveryError {
DeliveryFailed {
detail: String,
},
AckNotObserved {
detail: String,
},
}Expand description
Errors surfaced by a HandoffDelivery channel.
Variants
DeliveryFailed
The handle value and token could not be delivered to the backend.
AckNotObserved
The backend acknowledgement was not observed before the deadline.