pub fn build_hello_handler(
config: &BrokerServeConfig,
) -> Result<HelloHandler, BrokerServeError>Expand description
Build a Hello handler from one service definition and backend endpoint.
pub fn build_hello_handler(
config: &BrokerServeConfig,
) -> Result<HelloHandler, BrokerServeError>Build a Hello handler from one service definition and backend endpoint.