pub struct BrokerLaunchServeConfig {
pub socket_path: String,
pub service_definition_dir: PathBuf,
pub max_connections: Option<NonZeroUsize>,
}Expand description
Configuration for serve mode that launches backends on Hello miss.
Fields
socket_path: StringLocal socket path or Windows pipe name to bind.
service_definition_dir: PathBufDirectory containing <service>.servicedef protobuf files.
max_connections: Option<NonZeroUsize>Optional number of control-socket connections to accept before returning.
Implementations
Sourceimpl BrokerLaunchServeConfig
impl BrokerLaunchServeConfig
Sourcepub fn new(
socket_path: impl Into<String>,
max_connections: usize,
) -> Result<Self, BrokerServeError>
pub fn new( socket_path: impl Into<String>, max_connections: usize, ) -> Result<Self, BrokerServeError>
Build a launch-backed serve config using the platform service-definition directory.
Sourcepub fn unbounded(socket_path: impl Into<String>) -> Self
pub fn unbounded(socket_path: impl Into<String>) -> Self
Build an unbounded launch-backed serve config using the platform service-definition directory.
Sourcepub fn with_service_definition_dir(self, root: impl Into<PathBuf>) -> Self
pub fn with_service_definition_dir(self, root: impl Into<PathBuf>) -> Self
Override the service-definition directory.
Sourcepub fn connection_limit(&self) -> ControlSocketConnectionLimit
pub fn connection_limit(&self) -> ControlSocketConnectionLimit
Return the configured accept-loop connection limit.