pub enum SpawnLockError {
Open {
path: PathBuf,
source: Error,
},
AlreadyLocked {
path: PathBuf,
},
Lock {
path: PathBuf,
source: Error,
},
DeletedOrRecreated {
path: PathBuf,
opened_identity: Option<SpawnLockFileIdentity>,
current_identity: Option<SpawnLockFileIdentity>,
},
Identity {
path: PathBuf,
source: Error,
},
}Expand description
Errors returned while acquiring a backend spawn lock.
Variants
Open
The lock path could not be opened or created.
AlreadyLocked
Another broker worker already owns the lock.
Lock
The platform lock operation failed for a reason other than contention.
DeletedOrRecreated
The lock path no longer names the file that was locked.
Fields

opened_identity: Option<SpawnLockFileIdentity>Identity of the opened file handle.

current_identity: Option<SpawnLockFileIdentity>Identity currently reachable through the lock path.
Identity
File identity could not be read.