pub struct SpawnWaitPolicy { /* private fields */ }Expand description
Policy for deciding one step of the backend daemon ready wait.
Implementations
Sourceimpl SpawnWaitPolicy
impl SpawnWaitPolicy
Sourcepub fn with_hard_ceiling(hard_ceiling: Duration) -> Self
pub fn with_hard_ceiling(hard_ceiling: Duration) -> Self
Create a policy with an explicit hard ceiling.
Sourcepub fn hard_ceiling(&self) -> Duration
pub fn hard_ceiling(&self) -> Duration
Return the configured hard ceiling.
Sourcepub fn backoff_for_attempt(&self, attempt: usize) -> Duration
pub fn backoff_for_attempt(&self, attempt: usize) -> Duration
Return the adaptive backoff for a zero-based probe attempt.
Attempts beyond the explicit sequence are capped at the final 2-second step.
Sourcepub fn decide(&self, probe: SpawnWaitProbe) -> SpawnWaitDecision
pub fn decide(&self, probe: SpawnWaitProbe) -> SpawnWaitDecision
Decide what the wait loop should do after one daemon/endpoint probe.