pub struct PruneOptions {
pub dormant_after_secs: Option<u64>,
pub keep_current: bool,
pub keep_last: Option<usize>,
pub service: Option<String>,
pub version: Option<String>,
pub confirm: bool,
}Expand description
Prune selection options.
Fields
dormant_after_secs: Option<u64>Only prune manifests inactive for at least this many seconds.
keep_current: boolKeep manifests with a current daemon.
keep_last: Option<usize>Keep the N most recently active manifests per service.
service: Option<String>Restrict to one service.
version: Option<String>Restrict to one version.
confirm: boolDelete selected paths. False means dry-run.