pub enum DaemonFrameDecode {
NeedMoreBytes,
Frame {
frame: DaemonFrame,
consumed: usize,
},
}Expand description
Incremental daemon-frame decoding result.
Variants
NeedMoreBytes
More bytes are necessary for either the frozen header or its body.
Frame
One complete decoded frame and the exact number of input bytes it used.
Fields

frame: DaemonFrameCanonical decoded frame.