Module host_identity

Module host_identity 

Host facts stamped into a newly-built manifest.

Functions

current
Return the current host identity using the current directory as the filesystem-device probe.
current_for_path
Return the current host identity, including the filesystem device id for path when the platform exposes it.