pub fn current() -> HostIdentityExpand description
Return the current host identity using the current directory as the filesystem-device probe.
pub fn current() -> HostIdentityReturn the current host identity using the current directory as the filesystem-device probe.