current_for_path

Function current_for_path 

pub fn current_for_path(path: &Path) -> HostIdentity
Return the current host identity, including the filesystem device id for path when the platform exposes it.