pub struct CacheManifestBuilder { /* private fields */ }Expand description
Builder for a frozen v1 cache manifest.
Implementations
Sourceimpl CacheManifestBuilder
impl CacheManifestBuilder
Sourcepub fn new(
service_name: impl Into<String>,
service_version: impl Into<String>,
) -> Self
pub fn new( service_name: impl Into<String>, service_version: impl Into<String>, ) -> Self
Begin a manifest for this application-selected service and version.
Sourcepub fn broker_instance(self, instance: impl Into<String>) -> Self
pub fn broker_instance(self, instance: impl Into<String>) -> Self
Record the application-selected broker-instance label.
Sourcepub fn root(self, kind: CacheRootKind, path: impl Into<String>) -> Self
pub fn root(self, kind: CacheRootKind, path: impl Into<String>) -> Self
Append one root, retaining caller order in the v1 record.
Sourcepub fn build(self) -> Result<CacheManifest, DaemonRegistrationError>
pub fn build(self) -> Result<CacheManifest, DaemonRegistrationError>
Build and SHA-256 seal this manifest without persisting it.
Sourcepub fn publish(self) -> Result<PathBuf, DaemonRegistrationError>
pub fn publish(self) -> Result<PathBuf, DaemonRegistrationError>
Build, seal, and atomically publish this manifest in the default registry.
Sourcepub fn publish_in(
self,
registry_dir: impl AsRef<Path>,
) -> Result<PathBuf, DaemonRegistrationError>
pub fn publish_in( self, registry_dir: impl AsRef<Path>, ) -> Result<PathBuf, DaemonRegistrationError>
Build, seal, and atomically publish this manifest in registry_dir.