try_decode_framed

Function try_decode_framed 

pub fn try_decode_framed(
    buf: &[u8],
) -> Result<Option<DecodedFramed>, FramingError>
Incrementally decode one Frame from the front of buf.

Returns Ok(None) without consuming or interpreting a partial header or body. Foreign framing versions, oversize declarations, and malformed protobuf bodies are terminal errors for the current connection.