macro_rules! rp_rust_debug_scope {
($label:expr) => { ... };
}Expand description
Create a scoped Rust debug trace label for the current function body.
macro_rules! rp_rust_debug_scope {
($label:expr) => { ... };
}Create a scoped Rust debug trace label for the current function body.