#[repr(i32)]pub enum ObserverBackpressure {
DropOldest = 0,
Block = 1,
}Expand description
Backpressure for the bounded observer sink. Mirrors TeeBackpressure semantics: DropOldest never blocks the emitter, Block waits.
Variants
Implementations
Sourceimpl ObserverBackpressure
impl ObserverBackpressure
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ObserverBackpressure.
Sourcepub fn from_i32(value: i32) -> Option<ObserverBackpressure>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ObserverBackpressure>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ObserverBackpressure, or None if value is not a valid variant.
Sourceimpl ObserverBackpressure
impl ObserverBackpressure
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.