#[repr(i32)]pub enum ObserverEventCategory {
Lifecycle = 0,
File = 1,
Network = 2,
Process = 3,
}Expand description
EventCategory values match observer::EventCategory integer ordering:
0=Lifecycle, 1=File, 2=Network, 3=Process. Phase 1 only honors Lifecycle;
the others are accepted (so the client can request them ahead of Phase 3
platform backends) but currently produce no events.
Variants
Implementations
Sourceimpl ObserverEventCategory
impl ObserverEventCategory
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ObserverEventCategory.
Sourcepub fn from_i32(value: i32) -> Option<ObserverEventCategory>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ObserverEventCategory>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ObserverEventCategory, or None if value is not a valid variant.
Sourceimpl ObserverEventCategory
impl ObserverEventCategory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.