pub struct AttachPipeStreamResponse {
pub backlog: Vec<u8>,
pub backlog_truncated: bool,
pub bytes_missed: u64,
}Fields
backlog: Vec<u8>Initial backlog the client missed before this attach. Same semantics as AttachPtySessionResponse: empty if nothing has been emitted yet.
backlog_truncated: boolbytes_missed: u64Trait Implementations
Sourceimpl Clone for AttachPipeStreamResponse
impl Clone for AttachPipeStreamResponse
Sourcefn clone(&self) -> AttachPipeStreamResponse
fn clone(&self) -> AttachPipeStreamResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachPipeStreamResponse
impl Debug for AttachPipeStreamResponse
Sourceimpl Default for AttachPipeStreamResponse
impl Default for AttachPipeStreamResponse
impl Eq for AttachPipeStreamResponse
Sourceimpl Hash for AttachPipeStreamResponse
impl Hash for AttachPipeStreamResponse
Sourceimpl Message for AttachPipeStreamResponse
impl Message for AttachPipeStreamResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AttachPipeStreamResponse
impl PartialEq for AttachPipeStreamResponse
Sourcefn eq(&self, other: &AttachPipeStreamResponse) -> bool
fn eq(&self, other: &AttachPipeStreamResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AttachPipeStreamResponse