pub struct AttachPtySessionRequest {
pub session_id: String,
pub rows: u32,
pub cols: u32,
pub steal: bool,
pub term: String,
pub is_tty: bool,
pub graphics_capabilities: Option<TerminalGraphicsCapabilities>,
}Fields
session_id: Stringrows: u32Client-side terminal dimensions; daemon resizes the PTY to match.
cols: u32steal: boolIf true, evict any currently-attached client. Default false: a second attach attempt fails with STATUS_CODE_ALREADY_ATTACHED.
term: StringTerminal capabilities for renegotiation; informational only for now.
is_tty: boolgraphics_capabilities: Option<TerminalGraphicsCapabilities>Trait Implementations
Sourceimpl Clone for AttachPtySessionRequest
impl Clone for AttachPtySessionRequest
Sourcefn clone(&self) -> AttachPtySessionRequest
fn clone(&self) -> AttachPtySessionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachPtySessionRequest
impl Debug for AttachPtySessionRequest
Sourceimpl Default for AttachPtySessionRequest
impl Default for AttachPtySessionRequest
Sourceimpl Message for AttachPtySessionRequest
impl Message for AttachPtySessionRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AttachPtySessionRequest
impl PartialEq for AttachPtySessionRequest
Sourcefn eq(&self, other: &AttachPtySessionRequest) -> bool
fn eq(&self, other: &AttachPtySessionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AttachPtySessionRequest