pub struct RegisterSessionTeeRequest {
pub session_id: String,
pub session_kind: i32,
pub stream: i32,
pub sink_kind: i32,
pub file_path: Vec<u8>,
pub file_mode: i32,
pub queue_capacity: u32,
pub suppress_missed_markers: bool,
pub backpressure: i32,
}Fields
session_id: Stringsession_kind: i32stream: i32sink_kind: i32file_path: Vec<u8>OS-native path bytes: Unix = OsStr bytes; Windows = little-endian UTF-16.
file_mode: i32queue_capacity: u320 means use the daemon default.
suppress_missed_markers: boolfalse means write missed-byte markers, matching the Rust default.
backpressure: i32Implementations
Sourceimpl RegisterSessionTeeRequest
impl RegisterSessionTeeRequest
Sourcepub fn session_kind(&self) -> TeeSessionKind
pub fn session_kind(&self) -> TeeSessionKind
Returns the enum value of session_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_session_kind(&mut self, value: TeeSessionKind)
pub fn set_session_kind(&mut self, value: TeeSessionKind)
Sets session_kind to the provided enum value.
Sourcepub fn stream(&self) -> TeeStreamKind
pub fn stream(&self) -> TeeStreamKind
Returns the enum value of stream, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stream(&mut self, value: TeeStreamKind)
pub fn set_stream(&mut self, value: TeeStreamKind)
Sets stream to the provided enum value.
Sourcepub fn sink_kind(&self) -> TeeSinkKind
pub fn sink_kind(&self) -> TeeSinkKind
Returns the enum value of sink_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sink_kind(&mut self, value: TeeSinkKind)
pub fn set_sink_kind(&mut self, value: TeeSinkKind)
Sets sink_kind to the provided enum value.
Sourcepub fn file_mode(&self) -> TeeFileMode
pub fn file_mode(&self) -> TeeFileMode
Returns the enum value of file_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_file_mode(&mut self, value: TeeFileMode)
pub fn set_file_mode(&mut self, value: TeeFileMode)
Sets file_mode to the provided enum value.
Sourcepub fn backpressure(&self) -> TeeBackpressure
pub fn backpressure(&self) -> TeeBackpressure
Returns the enum value of backpressure, or the default if the field is set to an invalid enum value.
Sourcepub fn set_backpressure(&mut self, value: TeeBackpressure)
pub fn set_backpressure(&mut self, value: TeeBackpressure)
Sets backpressure to the provided enum value.