pub struct TerminalGraphicsCapabilities {
pub protocols: Vec<TerminalGraphicsCapability>,
pub preferred: i32,
}Fields
protocols: Vec<TerminalGraphicsCapability>preferred: i32Implementations
Sourceimpl TerminalGraphicsCapabilities
impl TerminalGraphicsCapabilities
Sourcepub fn preferred(&self) -> GraphicsProtocol
pub fn preferred(&self) -> GraphicsProtocol
Returns the enum value of preferred, or the default if the field is set to an invalid enum value.
Sourcepub fn set_preferred(&mut self, value: GraphicsProtocol)
pub fn set_preferred(&mut self, value: GraphicsProtocol)
Sets preferred to the provided enum value.