PtySlave

Trait PtySlave 

pub trait PtySlave: Send + 'static {
    type Child: PtyChild;

    // Required method
    fn spawn(
        self,
        argv: &[OsString],
        cwd: Option<&Path>,
        env: Option<&[(OsString, OsString)]>,
    ) -> Result<Self::Child>;
}
Platform-neutral handle for the slave side of a pseudo-terminal.

Required Associated Types

type Child: PtyChild

Child process type produced by this slave handle.

Required Methods

fn spawn( self, argv: &[OsString], cwd: Option<&Path>, env: Option<&[(OsString, OsString)]>, ) -> Result<Self::Child>

Spawn a child process attached to this slave PTY.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors