pub struct TerminalInputEventRecord {
pub data: Vec<u8>,
pub submit: bool,
pub shift: bool,
pub ctrl: bool,
pub alt: bool,
pub virtual_key_code: u16,
pub repeat_count: u16,
}Expand description
A translated terminal input event ready to forward to a PTY.
Fields
data: Vec<u8>Bytes to write to the PTY for this event.
submit: boolWhether this event represents an unmodified Enter submit action.
shift: boolWhether Shift was active when the event was captured.
ctrl: boolWhether Ctrl was active when the event was captured.
alt: boolWhether Alt was active when the event was captured.
virtual_key_code: u16Virtual-key code for the source key event.
repeat_count: u16Number of key repeats represented by this event.