EndpointProbeError

Enum EndpointProbeError 

pub enum EndpointProbeError {
Show 15 variants Random(Error), LocalSocketName(Error), Connect(Error), ConfigureNonblocking(Error), Timeout, Io(Error), UnsupportedFramingVersion { got: u8, expected: u8, }, FrameTooLarge { body_length: usize, cap: usize, }, EncodeFrame(EncodeError), DecodeFrame(DecodeError), UnexpectedFrame(&'static str), MalformedPayload(&'static str), DecodeDaemonProcess(DecodeError), Identity(IdentityError), IdentityMismatch { field: &'static str, },
}
Errors returned by the active endpoint-response probe.

Variants



Random(Error)

The probe nonce could not be generated.



LocalSocketName(Error)

The endpoint path/name could not be converted to a local socket name.



Connect(Error)

Connecting to the endpoint failed.



ConfigureNonblocking(Error)

The stream could not be switched to nonblocking mode for deadline I/O.



Timeout

Probe I/O exceeded the configured deadline.



Io(Error)

Raw probe I/O failed.



UnsupportedFramingVersion

The peer used the wrong broker framing byte.

Fields

got: u8

Framing byte received from the peer.

expected: u8

Framing byte expected by v1.



FrameTooLarge

The peer advertised a frame that exceeds the v1 frame cap.

Fields

body_length: usize

Advertised frame body length.

cap: usize

Maximum accepted frame body length.



EncodeFrame(EncodeError)

The outbound probe request frame could not be encoded.



DecodeFrame(DecodeError)

The response frame could not be decoded.



UnexpectedFrame(&'static str)

The response frame did not match the endpoint-probe contract.



MalformedPayload(&'static str)

The response payload did not match the endpoint-probe contract.



DecodeDaemonProcess(DecodeError)

The response daemon identity could not be decoded.



Identity(IdentityError)

The response daemon identity was malformed.



IdentityMismatch

The response daemon identity did not match the expected identity.

Fields

field: &'static str

First mismatched identity field.