pub struct Frame {
pub envelope_version: u32,
pub kind: i32,
pub payload_protocol: u32,
pub payload: Vec<u8>,
pub request_id: u64,
pub payload_encoding: i32,
pub deadline_unix_ms: u64,
pub traceparent: String,
pub tracestate: String,
}Expand description
Every control-plane frame on a broker connection.
Fields
envelope_version: u32ALWAYS 1 in v1 broker. Frozen.
kind: i32payload_protocol: u320x00 for Hello/HelloReply; 0xAD01 for admin verbs
payload: Vec<u8>OPAQUE for non-control kinds
request_id: u64payload_encoding: i32deadline_unix_ms: u64traceparent: StringW3C trace context
tracestate: StringImplementations
Sourceimpl Frame
impl Frame
Sourcepub fn kind(&self) -> FrameKind
pub fn kind(&self) -> FrameKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn payload_encoding(&self) -> PayloadEncoding
pub fn payload_encoding(&self) -> PayloadEncoding
Returns the enum value of payload_encoding, or the default if the field is set to an invalid enum value.
Sourcepub fn set_payload_encoding(&mut self, value: PayloadEncoding)
pub fn set_payload_encoding(&mut self, value: PayloadEncoding)
Sets payload_encoding to the provided enum value.