pub struct PtySpawnRequest {
pub argv: Vec<String>,
pub cwd: Option<PathBuf>,
pub env: Vec<(String, String)>,
pub clear_inherited_env: bool,
pub rows: u16,
pub cols: u16,
pub originator: Option<String>,
}Expand description
Request shape for spawning a daemon-owned PTY session.
Fields
argv: Vec<String>Command and arguments to execute inside the PTY.
cwd: Option<PathBuf>Working directory for the spawned process.
env: Vec<(String, String)>Environment variables to add or override for the spawned process.
clear_inherited_env: boolWhether to start from an empty environment instead of inheriting the daemon’s environment.
rows: u16Initial terminal row count.
cols: u16Initial terminal column count.
originator: Option<String>Optional caller-defined owner string used for listing and filtering sessions.
Implementations
Sourceimpl PtySpawnRequest
impl PtySpawnRequest
Sourcepub fn new<S: Into<String>>(argv: impl IntoIterator<Item = S>) -> Self
pub fn new<S: Into<String>>(argv: impl IntoIterator<Item = S>) -> Self
Create a spawn request with default size and inherited environment.
Sourcepub fn with_cwd(self, cwd: impl Into<PathBuf>) -> Self
pub fn with_cwd(self, cwd: impl Into<PathBuf>) -> Self
Set the working directory for the spawned process.
Sourcepub fn with_originator(self, originator: impl Into<String>) -> Self
pub fn with_originator(self, originator: impl Into<String>) -> Self
Set the caller-defined owner string for this session.