Host facts stamped into a newly-built manifest.
Functions
- current
- Return the current host identity using the current directory as the filesystem-device probe.
- current_
for_ path - Return the current host identity, including the filesystem device id
for
pathwhen the platform exposes it.