pub fn current_for_path(path: &Path) -> HostIdentityExpand description
Return the current host identity, including the filesystem device id
for path when the platform exposes it.
pub fn current_for_path(path: &Path) -> HostIdentityReturn the current host identity, including the filesystem device id
for path when the platform exposes it.