user_baseline_environment

Function user_baseline_environment 

pub fn user_baseline_environment() -> Result<Vec<(OsString, OsString)>>
Return the logged-in user’s baseline environment.

On Windows this is freshly constructed from machine and user settings and therefore excludes variables that exist only in the current process. On Unix this currently falls back to the current process environment.