#[repr(i32)]pub enum TeeSinkKind {
Unspecified = 0,
File = 1,
}Variants
Unspecified = 0
File = 1
Daemon opens the path and owns the file descriptor until the tee is removed or the session ends. Path bytes are OS-native, not UTF-8.
Implementations
Sourceimpl TeeSinkKind
impl TeeSinkKind
Sourceimpl TeeSinkKind
impl TeeSinkKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.