pub struct TerminalGraphicsCapability {
pub protocol: i32,
pub status: i32,
pub evidence: i32,
pub source: String,
pub risks: Vec<String>,
}Fields
protocol: i32status: i32evidence: i32source: Stringrisks: Vec<String>Implementations
Sourceimpl TerminalGraphicsCapability
impl TerminalGraphicsCapability
Sourcepub fn protocol(&self) -> GraphicsProtocol
pub fn protocol(&self) -> GraphicsProtocol
Returns the enum value of protocol, or the default if the field is set to an invalid enum value.
Sourcepub fn set_protocol(&mut self, value: GraphicsProtocol)
pub fn set_protocol(&mut self, value: GraphicsProtocol)
Sets protocol to the provided enum value.
Sourcepub fn status(&self) -> CapabilityStatus
pub fn status(&self) -> CapabilityStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: CapabilityStatus)
pub fn set_status(&mut self, value: CapabilityStatus)
Sets status to the provided enum value.
Sourcepub fn evidence(&self) -> EvidenceStrength
pub fn evidence(&self) -> EvidenceStrength
Returns the enum value of evidence, or the default if the field is set to an invalid enum value.
Sourcepub fn set_evidence(&mut self, value: EvidenceStrength)
pub fn set_evidence(&mut self, value: EvidenceStrength)
Sets evidence to the provided enum value.