Cross-platform PTY backend traits and platform-selected implementations.
Host-neutral PTY facade owned by running-process-platform-internal.
Structs
- PtySize
- Caller-facing PTY dimensions.
Traits
- PtyBackend
- Factory trait implemented by the selected host PTY backend.
- PtyChild
- Platform-neutral handle for a child process running inside a PTY.
- PtyMaster
- Platform-neutral handle for the master side of a pseudo-terminal.
- PtySlave
- Platform-neutral handle for the slave side of a pseudo-terminal.