pub fn spawn_daemon_with_stdio(
command: &mut Command,
stdio: DaemonStdio<'_>,
) -> Result<DaemonChild>Expand description
Spawn a detached daemon with file-or-NUL stdout and stderr.
Stdin remains connected to null. The supplied handles are duplicated into the sanitized child handle list, so the caller can close its files after this function returns without affecting the daemon.